@@ -4,7 +4,7 @@
 : "${BUILDDIR:=./debian/build}"
 : "${DEB_HOST_ARCH:=$(dpkg --print-architecture)}"
 
-if "$BUILDDIR/dist/bin/js" -e 'print("Hello, world")'; then
+if "$BUILDDIR/js/src/js" -e 'print("Hello, world")'; then
 	echo "Smoke-test successful, continuing with full test suite"
 else
 	echo "Smoke-test failed: did interpreter initialization fail? (see #873778)"
@@ -27,7 +27,7 @@ fi
 # we want to expand --exclude to several arguments
 # shellcheck disable=SC2086
 if "${BUILDDIR}"/dist/bin/run-mozilla.sh \
-   "${BUILDDIR}"/_virtualenvs/init_py3/bin/python -u \
+   "${BUILDDIR}"/_virtualenvs/common/bin/python3 -u \
    "${SRCDIR}"/jit-test/jit_test.py \
    --format=automation \
    --no-slow \
